FORMAT_TO_EXTENSION = {
    "asciidoc": "adoc",
    "adoc": "adoc",
    "beamer": "pdf",
    "commonmark": "md",
    "context": "ctx",
    "ctx": "ctx",
    "docbook": "dbk",
    "docbook4": "dbk",
    "docbook5": "dbk",
    "dbk": "dbk",
    "docx": "docx",
    "dzslides": "html",
    "epub": "epub",
    "epub2": "epub",
    "epub3": "epub",
    "fb2": "fb2",
    "gfm": "md",
    "haddock": "html",
    "html": "html",
    "html4": "html",
    "html5": "html",
    "icml": "icml",
    "jats": "jats",
    "json": "json",
    "latex": "latex",
    "man": "man",
    "markdown": "md",
    "markdown_github": "md",
    "markdown_mmd": "md",
    "markdown_phpextra": "md",
    "markdown_strict": "md",
    "markdown+lhs": "lhs",
    "lhs": "lhs",
    "md": "md",
    "mediawiki": "html",
    "ms": "ms",
    "muse": "muse",
    "odt": "odt",
    "opendocument": "odt",
    "opml": "opml",
    "org": "org",
    "pdf": "pdf",
    "plain": "txt",
    "pptx": "pptx",
    "revealjs": "html",
    "rst": "rst",
    "rtf": "rtf",
    "s5": "s5",
    "slideous": "html",
    "slidy": "html",
    "tei": "tei",
    "texinfo": "texi",
    "textile": "tex",
    "zimwiki": "html",
}
